==> open-xchange-documents-backend_7.4.2.orig.tar.bz2: open-xchange-documents-backend-7.4.2/com.openexchange.office.calcengine.core/src/com/openexchange/office/calcengine/client/impl/CalcEngineNativeWrapper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.office.calcengine.client.impl;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;

import com.openexchange.office.calcengine.JCalcDocumentWrapper;
import com.openexchange.office.calcengine.JOperation;
import com.openexchange.office.tools.logging.ELogLevel;

//=============================================================================
/** seams to be some kind of over engineering ... but is useful for testing purposes.
 *  E.g. mocking such JCalcDocumentWrapper isn't an easy job ... we can mock these
 *  implementation instead and write unit tests independent of JNI .-)
 */
public class CalcEngineNativeWrapper
{
    //-------------------------------------------------------------------------
    public CalcEngineNativeWrapper ()
        throws Exception
    {}
    
    //-------------------------------------------------------------------------
    public boolean createDocument(String sHandle)
        throws Exception
    {
        return JCalcDocumentWrapper.createDocument(sHandle);
    }
    
    //-------------------------------------------------------------------------
    public boolean destroyDocument(final String sHandle)
        throws Exception
    {
        return JCalcDocumentWrapper.destroyDocument(sHandle);
    }
    
    //-------------------------------------------------------------------------
    public boolean executeOperation(final String     sHandle   ,
                                    final JOperation aOperation)
        throws Exception
    {
        return JCalcDocumentWrapper.executeOperation(sHandle, aOperation);
    }

    //-------------------------------------------------------------------------
    public List< String > getHandleList()
        throws Exception
    {
    	final String         LIST_SEPERATOR = ",";
    	final List< String > EMPTY_LIST     = new ArrayList< String > ();
    	final String         sHandleList    = JCalcDocumentWrapper.getAllHandles();
    	
    	if (StringUtils.isEmpty(sHandleList))
    		return EMPTY_LIST;

    	final List< String > lHandles       = new ArrayList< String > ();
    	final String[]       lParsedHandles = StringUtils.splitByWholeSeparatorPreserveAllTokens(sHandleList, LIST_SEPERATOR);
    	
    	if (lParsedHandles == null)
    		return EMPTY_LIST;

    	for (String sParsedHandle : lParsedHandles)
    	{
    		if (StringUtils.isEmpty(sParsedHandle))
    			continue;
    		lHandles.add(sParsedHandle);
    	}
    	
    	return lHandles;
    }

    //-------------------------------------------------------------------------
    public String getHandleNames()
        throws Exception
    {
        return JCalcDocumentWrapper.getAllHandles();
    }

    //-------------------------------------------------------------------------
    public String getVersion()
        throws Exception
    {
        return JCalcDocumentWrapper.getVersion();
    }

    //-------------------------------------------------------------------------
    public void setLogLevel(final ELogLevel eLevel)
        throws Exception
    {
    	final int nLevel = ELogLevel.toInt(eLevel);
        JCalcDocumentWrapper.setLogLevel(nLevel);
    }
}

==> open-xchange-documents-backend_7.6.0.orig.tar.bz2: open-xchange-documents-backend-7.6.0/com.openexchange.office.calcengine.core/src/com/openexchange/office/calcengine/client/impl/CalcEngineNativeWrapper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.office.calcengine.client.impl;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;

import com.openexchange.office.calcengine.JCalcDocumentWrapper;
import com.openexchange.office.tools.logging.ELogLevel;

//=============================================================================
/** seams to be some kind of over engineering ... but is useful for testing purposes.
 *  E.g. mocking such JCalcDocumentWrapper isn't an easy job ... we can mock these
 *  implementation instead and write unit tests independent of JNI .-)
 */
public class CalcEngineNativeWrapper
{
    //-------------------------------------------------------------------------
    public CalcEngineNativeWrapper ()
        throws Exception
    {}
    
    //-------------------------------------------------------------------------
    public boolean createDocument(String sHandle)
        throws Exception
    {
        return JCalcDocumentWrapper.createDocument(sHandle);
    }
    
    //-------------------------------------------------------------------------
    public boolean destroyDocument(final String sHandle)
        throws Exception
    {
        return JCalcDocumentWrapper.destroyDocument(sHandle);
    }
    
    //-------------------------------------------------------------------------
    public String executeOperation(final String     sHandle   ,
                                    final String     sOperation)
        throws Exception
    {
        return JCalcDocumentWrapper.executeOperation(sHandle, sOperation);
    }

    //-------------------------------------------------------------------------
    public List< String > getHandleList()
        throws Exception
    {
    	final String         LIST_SEPERATOR = ",";
    	final List< String > EMPTY_LIST     = new ArrayList< String > ();
    	final String         sHandleList    = JCalcDocumentWrapper.getAllHandles();
    	
    	if (StringUtils.isEmpty(sHandleList))
    		return EMPTY_LIST;

    	final List< String > lHandles       = new ArrayList< String > ();
    	final String[]       lParsedHandles = StringUtils.splitByWholeSeparatorPreserveAllTokens(sHandleList, LIST_SEPERATOR);
    	
    	if (lParsedHandles == null)
    		return EMPTY_LIST;

    	for (String sParsedHandle : lParsedHandles)
    	{
    		if (StringUtils.isEmpty(sParsedHandle))
    			continue;
    		lHandles.add(sParsedHandle);
    	}
    	
    	return lHandles;
    }

    //-------------------------------------------------------------------------
    public String getHandleNames()
        throws Exception
    {
        return JCalcDocumentWrapper.getAllHandles();
    }

    //-------------------------------------------------------------------------
    public String getVersion()
        throws Exception
    {
        return JCalcDocumentWrapper.getVersion();
    }

    //-------------------------------------------------------------------------
    public void setLogLevel(final ELogLevel eLevel)
        throws Exception
    {
    	final int nLevel = ELogLevel.toInt(eLevel);
        JCalcDocumentWrapper.setLogLevel(nLevel);
    }
}
